@@ -1,16 +1,17 @@
 #!/bin/bash
 # textsearch_ja	(http://textsearch-ja.projects.postgresql.org/index-ja.html)
-#	BuildScript for Plamo Linux 4.51
-#			by Jun Kuwamura <juk@linet.gr.jp> on 2009-02-07
+#	BuildScript for Plamo Linux 4.7
+#			by Jun Kuwamura <juk@linet.gr.jp> on 2009-12-14
 # require:
-#	postgresql-8.3.x
+#	postgresql-8.4.x
 #
-SRC_URI=http://pgfoundry.org/frs/download.php/2186/textsearch_ja-8.4.1.tar.gz
+SRC_URI=http://pgfoundry.org/frs/download.php/2287/textsearch_ja-8.4.2.tar.gz
 SRC_FILE=${SRC_URI##*/}
 PAC_NAME=${SRC_FILE%%.tar.gz}
 #VERSION=${PAC_NAME##*-}
-VERSION=8.3.7
-DIR_NAME=textsearch_ja
+VERSION=8.4.2
+#DIR_NAME=textsearch_ja
+DIR_NAME=$PAC_NAME
 echo $DIR_NAME $VERSION
 POSTGRESQL=postgresql-$VERSION
 
@@ -21,7 +22,7 @@ SYS_NAME="${CPU}-${REL}"
 
 PLAMO=/expo/Build
 #SRC_DIR=$PLAMO/Archive/%category%
-PAC_DIR=$PLAMO/Packages/4.6/09_webdb/01_PostgreSQL.tgz
+PAC_DIR=$PLAMO/Packages/4.7/09_webdb/01_PostgreSQL.tgz
 BUILD_DIR=$PLAMO/pgfoundry
 CUSTOM_DIR=$BUILD_DIR/Custom
 PAT_FILE=
@@ -54,7 +55,7 @@ mkdir -p work
  cd work/
 
  mkdir -p opt/$POSTGRESQL/lib/
- cp -p ../libtextsearch_ja.so.0.0 opt/$POSTGRESQL/lib/libtextsearch_ja.so
+ cp -p ../textsearch_ja.so opt/$POSTGRESQL/lib/textsearch_ja.so
  mkdir -p opt/$POSTGRESQL/share/contrib/
  cp -p ../textsearch_ja.sql ../uninstall_textsearch_ja.sql \
    opt/$POSTGRESQL/share/contrib/
